#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

from onf_website import _
# import packages
from onf_website.skin.public import owl_carousel_init, jquery_twentytwenty_init
# import interfaces
from pyams_content.component.gallery.interfaces import IGallery
from pyams_content.features.renderer.interfaces import IContentRenderer
from pyams_content.features.renderer.skin import BaseContentRenderer
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config


class BaseGalleryRenderer(BaseContentRenderer):
    """Base gallery renderer"""

    i18n_context_attrs = ('title','description')


@adapter_config(name='default', context=(IGallery, IPyAMSLayer), provides=IContentRenderer)
@template_config(template='templates/gallery-carousel.pt', layer=IPyAMSLayer)
class ONFDefaultGalleryCarouselParagraphRenderer(BaseGalleryRenderer):
    """Default gallery renderer"""

    label = _("ONF: Horizontal carousel")
    weight = 1

    resources = (owl_carousel_init, )


@adapter_config(name='before-after', context=(IGallery, IPyAMSLayer), provides=IContentRenderer)
@template_config(template='templates/gallery-before-after.pt', layer=IPyAMSLayer)
class ONFGalleryParagraphBeforeAfterRenderer(BaseGalleryRenderer):
    """ONF gallery before/after renderer"""

    label = _("ONF: Dual images comparison")
    weight = 2

    image_before = None
    image_after = None

    def update(self):
        super(ONFGalleryParagraphBeforeAfterRenderer, self).update()
        medias = self.context.get_visible_medias()
        self.image_before = next(medias, None)
        self.image_after = next(medias, None)

    resources = (jquery_twentytwenty_init, )
