#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.features.footer.interfaces import IDefaultFooterRendererSettings
from pyams_content.component.association.interfaces import IAssociationInfo
from pyams_content.features.footer.interfaces import IFooterTarget, IFooterRenderer, IFooterSettings, \
    IFooterRendererSettings
from pyams_skin.layer import IPyAMSLayer

# import packages
from onf_website.features.footer import DefaultFooterRendererSettings
from pyams_content.features.footer.skin import BaseFooterRenderer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config

from onf_website import _


DEFAULT_FOOTER_RENDERER_NAME = 'ONF default footer'


#
# Default footer renderer
#

@adapter_config(name=DEFAULT_FOOTER_RENDERER_NAME, context=(IFooterTarget, IPyAMSLayer), provides=IFooterRenderer)
@adapter_config(name=DEFAULT_FOOTER_RENDERER_NAME, context=(IFooterSettings, IPyAMSLayer), provides=IFooterRenderer)
@template_config(template='templates/default-footer.pt', layer=IPyAMSLayer)
class ONFDefaultFooterRenderer(BaseFooterRenderer):
    """ONF default footer renderer"""

    name = DEFAULT_FOOTER_RENDERER_NAME
    label = _("ONF default footer")
    weight = 1

    settings_key = 'ONF::default'
    settings_interface = IDefaultFooterRendererSettings

    @staticmethod
    def get_link_info(link):
        return IAssociationInfo(link)


@adapter_config(context=ONFDefaultFooterRenderer, provides=IFooterRendererSettings)
def default_footer_renderer_settings_factory(context):
    """Default footer renderer settings factory"""
    return DefaultFooterRendererSettings()
